==> pyramid_amdjs-0.3.1.tar.gz: pyramid_amdjs-0.3.1/pyramid_amdjs/static/lib/curl.js <==
(function(){/*
 MIT License (c) copyright B Cavalier & J Hann */
var h=!0,m=!1,n=this.window||"undefined"!=typeof global&&global||this;function aa(){}function p(a,b){return 0==ba.call(a).indexOf("[object "+b)}function t(a){return a&&"/"==a.charAt(a.length-1)?a.substr(0,a.length-1):a}function ca(a,b){var c,d,e,f;c=1;d=a;"."==d.charAt(0)&&(e=h,d=d.replace(da,function(a,b,d,e){d&&c++;return e||""}));if(e){e=b.split("/");f=e.length-c;if(0>f)return a;e.splice(f,c);return e.concat(d||[]).join("/")}return d}
function u(a){var b=a.indexOf("!");return{l:a.substr(b+1),j:0<=b&&a.substr(0,b)}}function v(){}function w(a,b){v.prototype=a||x;var c=new v;v.prototype=x;for(var d in b)c[d]=b[d];return c}
function y(){function a(a,b,c){d.push([a,b,c])}function b(a,b){for(var c,e=0;c=d[e++];)(c=c[a])&&c(b)}var c,d,e;c=this;d=[];e=function(c,g){a=c?function(a){a&&a(g)}:function(a,b){b&&b(g)};e=aa;b(c?0:1,g);b=aa;d=z};this.ba=function(b,d,c){a(b,d,c)};this.h=function(a){c.na=a;e(h,a)};this.e=function(a){c.ma=a;e(m,a)};this.t=function(a){b(2,a)}}function A(a,b,c,d){a instanceof y?a.ba(b,c,d):b(a)}function B(a,b,c){var d;return function(){0<=--a&&b&&(d=b.apply(z,arguments));0==a&&c&&c(d);return d}}
function C(){var a=[].slice.call(arguments),b;p(a[0],"Object")&&(b=a.shift(),D(b));return new ea(a[0],a[1],a[2])}function D(a){a&&(E.L(a),F=E.a(a),E.O(a),"main"in a&&setTimeout(function(){var b;b=E.f(F,z,[].concat(a.main));E.g(b)},0))}function ea(a,b,c,d){var e;e=E.f(F,z,[].concat(a));this.then=a=function(a,b){A(e,function(b){a&&a.apply(z,b)},function(a){if(b)b(a);else throw a;});return this};this.next=function(a,b,d){return new ea(a,b,d,e)};this.config=D;(b||c)&&a(b,c);A(d,function(){E.g(e)})}
function fa(a){var b,c;b=a.id;if(b==z)if(G!==z)G={C:"Multiple anonymous defines in url"};else if(!(b=E.Y()))G=a;if(b!=z){c=H[b];b in H||(c=E.k(b,F),c=E.z(c.a,b),H[b]=c);if(!(c instanceof y))throw Error("duplicate define: "+b);c.ca=m;E.A(c,a)}}function I(){var a=E.V(arguments);fa(a)}
var F,J,M,N=n.document,O=N&&(N.head||N.getElementsByTagName("head")[0]),ga=O&&O.getElementsByTagName("base")[0]||null,ha={},ia={},P={},ja="addEventListener"in n?{}:{loaded:1,complete:1},x={},ba=x.toString,z,H={},Q=m,G,ka=/^\/|^[^:]+:\/\//,da=/(\.)(\.?)(?:$|\/([^\.\/]+.*)?)/g,la=/\/\*[\s\S]*?\*\/|(?:[^\\])\/\/.*?[\n\r]/g,ma=/require\s*\(\s*["']([^"']+)["']\s*\)|(?:[^\\]?)(["'])/g,R,E;
E={m:function(a,b,c){var d;a=ca(a,b);if("."==a.charAt(0))return a;d=u(a);a=(b=d.j)||d.l;a in c.c&&(a=c.c[a].H||a);b&&(0>b.indexOf("/")&&!(b in c.c)&&(a=t(c.J)+"/"+b),a=a+"!"+d.l);return a},f:function(a,b,c,d){function e(b){return E.m(b,g.id,a)}function f(b,c,f){var j;j=c&&function(a){c.apply(z,a)};if(p(b,"String")){if(j)throw Error("require(id, callback) not allowed");f=e(b);b=H[f];if(!(f in H))throw Error("Module not resolved: "+f);return(f=b instanceof y&&b.b)||b}A(E.g(E.f(a,g.id,b,d)),j,f)}var g;
g=new y;g.id=b||"";g.Z=d;g.B=c;g.a=a;g.u=f;f.toUrl=function(b){return E.k(e(b),a).url};g.m=e;return g},z:function(a,b,c){var d,e,f;d=E.f(a,b,z,c);e=d.h;f=B(1,function(a){d.p=a;try{return E.R(d)}catch(b){console.log(b),d.e(b)}});d.h=function(a){A(c||Q,function(){e(H[d.id]=f(a))})};d.D=function(a){A(c||Q,function(){d.b&&(f(a),d.t(ia))})};return d},P:function(a,b,c,d){return E.f(a,c,z,d)},X:function(a){return a.u},F:function(a){return a.b||(a.b={})},W:function(a){var b=a.q;b||(b=a.q={id:a.id,uri:E.G(a),
exports:E.F(a),config:function(){return a.a}},b.b=b.exports);return b},G:function(a){return a.url||(a.url=E.w(a.u.toUrl(a.id),a.a))},L:function(a){var b,c,d,e,f;b="curl";c="define";d=e=n;if(a&&(f=a.overwriteApi||a.ka,b=a.apiName||a.ea||b,d=a.apiContext||a.da||d,c=a.defineName||a.ga||c,e=a.defineContext||a.fa||e,J&&p(J,"Function")&&(n.curl=J),J=null,M&&p(M,"Function")&&(n.define=M),M=null,!f)){if(d[b]&&d[b]!=C)throw Error(b+" already exists");if(e[c]&&e[c]!=I)throw Error(c+" already exists");}d[b]=
C;e[c]=I},a:function(a){function b(a,b){var d,c,g,s,K;for(K in a){g=a[K];p(g,"String")&&(g={path:a[K]});g.name=g.name||K;s=e;c=u(t(g.name));d=c.l;if(c=c.j)s=f[c],s||(s=f[c]=w(e),s.c=w(e.c),s.d=[]),delete a[K];if(b){c=g;var L=void 0;c.path=t(c.path||c.location||"");L=c.main||"./main";"."==L.charAt(0)||(L="./"+L);c.H=ca(L,c.name+"/");c.a=c.config;c.a&&(c.a=w(e,c.a))}else c={path:t(g.path)};c.M=d.split("/").length;d?(s.c[d]=c,s.d.push(d)):s.n=E.K(g.path,e)}}function c(a){var b=a.c;a.I=RegExp("^("+a.d.sort(function(a,
c){return b[c].M-b[a].M}).join("|").replace(/\/|\./g,"\\$&")+")(?=\\/|$)");delete a.d}var d,e,f,g;"baseUrl"in a&&(a.n=a.baseUrl);"main"in a&&(a.H=a.main);"preloads"in a&&(a.la=a.preloads);"pluginPath"in a&&(a.J=a.pluginPath);if("dontAddFileExt"in a||a.i)a.i=RegExp(a.dontAddFileExt||a.i);d=F;e=w(d,a);e.c=w(d.c);f=a.plugins||{};e.plugins=w(d.plugins);e.s=w(d.s,a.s);e.r=w(d.r,a.r);e.d=[];b(a.packages,h);b(a.paths,m);for(g in f)a=E.m(g+"!","",e),e.plugins[a.substr(0,a.length-1)]=f[g];f=e.plugins;for(g in f)if(f[g]=
w(e,f[g]),a=f[g].d)f[g].d=a.concat(e.d),c(f[g]);for(g in d.c)e.c.hasOwnProperty(g)||e.d.push(g);c(e);return e},O:function(a){var b;(b=a&&a.preloads)&&0<b.length&&A(Q,function(){Q=E.g(E.f(F,z,b,h))})},k:function(a,b){var c,d,e,f;c=b.c;e=ka.test(a)?a:a.replace(b.I,function(a){d=c[a]||{};f=d.a;return d.path||""});return{a:f||F,url:E.K(e,b)}},K:function(a,b){var c=b.n;return c&&!ka.test(a)?t(c)+"/"+a:a},w:function(a,b){return a+((b||F).i.test(a)?"":".js")},$:function(a,b,c){var d=N.createElement("script");
d.onload=d.onreadystatechange=function(c){c=c||n.event;if("load"==c.type||ja[d.readyState])delete P[a.id],d.onload=d.onreadystatechange=d.onerror="",b()};d.onerror=function(){c(Error("Syntax or http error: "+a.url))};d.type=a.ha||"text/javascript";d.charset="utf-8";d.async=!a.ja;d.src=a.url;P[a.id]=d;O.insertBefore(d,ga);return d},S:function(a){var b=[],c;("string"==typeof a?a:a.toSource?a.toSource():a.toString()).replace(la,"").replace(ma,function(a,e,f){f?c=c==f?z:c:c||b.push(e);return""});return b},
V:function(a){var b,c,d,e,f,g;f=a.length;d=a[f-1];e=p(d,"Function")?d.length:-1;2==f?p(a[0],"Array")?c=a[0]:b=a[0]:3==f&&(b=a[0],c=a[1]);!c&&0<e&&(g=h,c=["require","exports","module"].slice(0,e).concat(E.S(d)));return{id:b,p:c||[],v:0<=e?d:function(){return d},o:g}},R:function(a){var b;b=a.v.apply(a.o?a.b:z,a.p);b===z&&a.b&&(b=a.q?a.b=a.q.b:a.b);return b},A:function(a,b){a.v=b.v;a.o=b.o;a.B=b.p;E.g(a)},g:function(a){function b(a,b,c){g[b]=a;c&&q(a,b)}function c(b,c){var d,e,f,g;d=B(1,function(a){e(a);
j(a,c)});e=B(1,function(a){q(a,c)});f=E.T(b,a);(g=f instanceof y&&f.b)&&e(g);A(f,d,a.e,a.b&&function(a){f.b&&(a==ha?e(f.b):a==ia&&d(f.b))})}function d(){a.h(g)}var e,f,g,k,l,q,j;g=[];f=a.B;k=f.length;0==f.length&&d();q=B(k,b,function(){a.D&&a.D(g)});j=B(k,b,d);for(e=0;e<k;e++)l=f[e],l in R?(j(R[l](a),e,h),a.b&&a.t(ha)):l?c(l,e):j(z,e,h);return a},U:function(a){E.G(a);E.$(a,function(){var b=G;G=z;a.ca!==m&&(!b||b.C?a.e(Error(b&&b.C||"define() missing or duplicated: "+a.url)):E.A(a,b))},a.e);return a},
T:function(a,b){var c,d,e,f,g,k,l,q,j,r,s;c=b.m;d=b.Z;e=b.a||F;f=u(c(a));l=f.l;g=f.j||l;q=E.k(g,e);if(f.j)k=g;else if(k=q.a.moduleLoader||q.a.ia)l=g,g=k,q=E.k(k,e);g in H?j=H[g]:(j=E.z(q.a,g,d),j.url=E.w(q.url,q.a),H[g]=j,E.U(j));g==k&&(r=new y,s=e.plugins[k]||e,A(j,function(a){var b,e,f;f=a.dynamic;l="normalize"in a?a.normalize(l,c,j.a)||"":c(l);e=k+"!"+l;b=H[e];if(!(e in H)){b=E.P(s,e,l,d);f||(H[e]=b);var g=function(a){b.h(a);f||(H[e]=a)};g.resolve=g;g.reject=g.error=b.e;a.load(l,b.u,g,s)}r!=b&&
A(b,r.h,r.e,r.t)},r.e));return r||j},Y:function(){var a;if(!p(n.opera,"Opera"))for(var b in P)if("interactive"==P[b].readyState){a=b;break}return a}};R={require:E.X,exports:E.F,module:E.W};C.version="0.7.3";C.config=D;I.amd={plugins:h,jQuery:h,curl:"0.7.3"};F={n:"",J:"curl/plugin",i:/\?|\.js\b/,s:{},r:{},plugins:{},c:{},I:/$^/};J=n.curl;M=n.define;!J||p(J,"Function")?E.L():(n.curl=z,D(J));H.curl=C;H["curl/_privileged"]={core:E,cache:H,config:function(){return F},_define:fa,_curl:C,Promise:y};
var S=this.document;function na(){if(!S.body)return m;T||(T=S.createTextNode(""));try{return S.body.removeChild(S.body.appendChild(T)),T=oa,h}catch(a){return m}}function U(){var a;a=pa[S[qa]]&&na();if(!V&&a){V=h;for(clearTimeout(ra);sa=ta.pop();)sa();ua&&(S[qa]="complete");for(var b;b=va.shift();)b()}return a}function wa(){U();V||(ra=setTimeout(wa,xa))}var qa="readyState",pa={loaded:1,interactive:1,complete:1},va=[],ua=S&&"string"!=typeof S[qa],V=m,xa=10,W,sa,ta=[],ra,oa,T;
W="addEventListener"in this?function(a,b){a.addEventListener(b,U,m);return function(){a.removeEventListener(b,U,m)}}:function(a,b){a.attachEvent("on"+b,U);return function(){a.detachEvent(b,U)}};S&&!U()&&(ta=[W(this,"load"),W(S,"readystatechange"),W(this,"DOMContentLoaded")],ra=setTimeout(wa,xa));define("curl/domReady",function(){function a(a){V?a():va.push(a)}a.then=a;a.amd=h;return a});define("curl/plugin/domReady",["../domReady"],function(a){return{load:function(b,c,d){a(d)}}});
function ya(){var a;a=X[za]("link");a.rel="stylesheet";a.type="text/css";return a}function Aa(a,b,c){Ba.push({url:a,N:b,Q:function(){c(Error(Ca))}});a=Da.shift();!a&&Ea.length<Fa&&(a=X.createElement("style"),Ea.push(a),Y.appendChild(a));a&&Ga(a)}function Ga(a){var b,c;b=Ba.shift();c=a.styleSheet;b?(a.onload=function(){b.N(b.aa);Ga(a)},a.onerror=function(){b.Q();Ga(a)},b.aa=c.imports[c.addImport(b.url)]):(a.onload=a.onerror=Z,Da.push(a))}
function Ha(a,b,c){if(!$.load){var d;var e,f;if(!a.href||X.readyState&&"complete"!=X.readyState)d=m;else{d=m;try{if(e=a.sheet)f=e.cssRules,d=null===f,!d&&f&&(e.insertRule("-curl-css-test {}",0),e.deleteRule(0),d=h)}catch(g){d="[object Opera]"!=Object.prototype.toString.call(window.opera)&&/security|denied/i.test(g.message)}}d?c(a.sheet):a.onload==Z||!a.onload||Ia(function(){Ha(a,b,c)},b)}}
function Ja(a,b,c,d){function e(){if(f.onload!=Z&&f.onload){f.onload=f.onerror=Z;var a=function(){!X.readyState||"complete"==X.readyState?b(f.sheet):Ia(a,10)};a()}}var f;f=ya();f.onload=function(){$.load=$.load||h;e()};Ha(f,d,e);f.onerror=function(){$.error=$.error||h;f.onload!=Z&&f.onload&&(f.onload=f.onerror=Z,c(Error(Ca)))};f.href=a;Y.appendChild(f)}function Z(){}
var za="createElement",Ia=this.setTimeout,X=this.document,Y,Ka=X&&X.createStyleSheet&&!(10<=X.documentMode),Ea=[],Da=[],Ba=[],Fa=12,La,Ca="HTTP or network error.",$={};X&&(Y=X.head||X.getElementsByTagName("head")[0],La=Ka?Aa:Ja);
define("curl/plugin/css",{normalize:function(a,b){var c,d;if(!a)return a;c=a.split(",");d=[];for(var e=0,f=c.length;e<f;e++)d.push(b(c[e]));return d.join(",")},load:function(a,b,c,d){function e(a){1<k.length&&g.push(a);0==--q&&c(1==k.length?a:g)}function f(a){(c.e||function(a){throw a;})(a)}var g,k,l,q,j;g=[];k=(a||"").split(",");l=d.cssWatchPeriod||50;d=d.cssNoWait;q=k.length;for(j=0;j<k.length;j++){a=k[j];var r;a=b.toUrl(a);a=a.lastIndexOf(".")<=a.lastIndexOf("/")?a+".css":a;d?(r=ya(),r.href=a,
Y.appendChild(r),e(r.sheet||r.styleSheet)):La(a,e,f,l)}},"plugin-builder":"./builder/css",pluginBuilder:"./builder/css"});
}).call(this);

==> pyramid_amdjs-0.5.3.tar.gz: pyramid_amdjs-0.5.3/pyramid_amdjs/static/lib/curl.js <==
(function(){/*
 MIT License (c) copyright B Cavalier & J Hann */
var h=!0,m=!1,n=this.window||"undefined"!=typeof global&&global||this;function aa(){}function p(a,b){return 0==ba.call(a).indexOf("[object "+b)}function t(a){return a&&"/"==a.charAt(a.length-1)?a.substr(0,a.length-1):a}function ca(a,b){var c,d,e,f;c=1;d=a;"."==d.charAt(0)&&(e=h,d=d.replace(da,function(a,b,d,e){d&&c++;return e||""}));if(e){e=b.split("/");f=e.length-c;if(0>f)return a;e.splice(f,c);return e.concat(d||[]).join("/")}return d}
function u(a){var b=a.indexOf("!");return{l:a.substr(b+1),j:0<=b&&a.substr(0,b)}}function v(){}function w(a,b){v.prototype=a||x;var c=new v;v.prototype=x;for(var d in b)c[d]=b[d];return c}
function y(){function a(a,b,c){d.push([a,b,c])}function b(a,b){for(var c,e=0;c=d[e++];)(c=c[a])&&c(b)}var c,d,e;c=this;d=[];e=function(c,g){a=c?function(a){a&&a(g)}:function(a,b){b&&b(g)};e=aa;b(c?0:1,g);b=aa;d=z};this.ba=function(b,d,c){a(b,d,c)};this.h=function(a){c.na=a;e(h,a)};this.e=function(a){c.ma=a;e(m,a)};this.t=function(a){b(2,a)}}function A(a,b,c,d){a instanceof y?a.ba(b,c,d):b(a)}function B(a,b,c){var d;return function(){0<=--a&&b&&(d=b.apply(z,arguments));0==a&&c&&c(d);return d}}
function C(){var a=[].slice.call(arguments),b;p(a[0],"Object")&&(b=a.shift(),D(b));return new ea(a[0],a[1],a[2])}function D(a){a&&(E.L(a),F=E.a(a),E.O(a),"main"in a&&setTimeout(function(){var b;b=E.f(F,z,[].concat(a.main));E.g(b)},0))}function ea(a,b,c,d){var e;e=E.f(F,z,[].concat(a));this.then=a=function(a,b){A(e,function(b){a&&a.apply(z,b)},function(a){if(b)b(a);else throw a;});return this};this.next=function(a,b,d){return new ea(a,b,d,e)};this.config=D;(b||c)&&a(b,c);A(d,function(){E.g(e)})}
function fa(a){var b,c;b=a.id;if(b==z)if(G!==z)G={C:"Multiple anonymous defines in url"};else if(!(b=E.Y()))G=a;if(b!=z){c=H[b];b in H||(c=E.k(b,F),c=E.z(c.a,b),H[b]=c);if(!(c instanceof y))throw Error("duplicate define: "+b);c.ca=m;E.A(c,a)}}function I(){var a=E.V(arguments);fa(a)}
var F,J,M,N=n.document,O=N&&(N.head||N.getElementsByTagName("head")[0]),ga=O&&O.getElementsByTagName("base")[0]||null,ha={},ia={},P={},ja="addEventListener"in n?{}:{loaded:1,complete:1},x={},ba=x.toString,z,H={},Q=m,G,ka=/^\/|^[^:]+:\/\//,da=/(\.)(\.?)(?:$|\/([^\.\/]+.*)?)/g,la=/\/\*[\s\S]*?\*\/|(?:[^\\])\/\/.*?[\n\r]/g,ma=/require\s*\(\s*["']([^"']+)["']\s*\)|(?:[^\\]?)(["'])/g,R,E;
E={m:function(a,b,c){var d;a=ca(a,b);if("."==a.charAt(0))return a;d=u(a);a=(b=d.j)||d.l;a in c.c&&(a=c.c[a].H||a);b&&(0>b.indexOf("/")&&!(b in c.c)&&(a=t(c.J)+"/"+b),a=a+"!"+d.l);return a},f:function(a,b,c,d){function e(b){return E.m(b,g.id,a)}function f(b,c,f){var j;j=c&&function(a){c.apply(z,a)};if(p(b,"String")){if(j)throw Error("require(id, callback) not allowed");f=e(b);b=H[f];if(!(f in H))throw Error("Module not resolved: "+f);return(f=b instanceof y&&b.b)||b}A(E.g(E.f(a,g.id,b,d)),j,f)}var g;
g=new y;g.id=b||"";g.Z=d;g.B=c;g.a=a;g.u=f;f.toUrl=function(b){return E.k(e(b),a).url};g.m=e;return g},z:function(a,b,c){var d,e,f;d=E.f(a,b,z,c);e=d.h;f=B(1,function(a){d.p=a;try{return E.R(d)}catch(b){console.log(b),d.e(b)}});d.h=function(a){A(c||Q,function(){e(H[d.id]=f(a))})};d.D=function(a){A(c||Q,function(){d.b&&(f(a),d.t(ia))})};return d},P:function(a,b,c,d){return E.f(a,c,z,d)},X:function(a){return a.u},F:function(a){return a.b||(a.b={})},W:function(a){var b=a.q;b||(b=a.q={id:a.id,uri:E.G(a),
exports:E.F(a),config:function(){return a.a}},b.b=b.exports);return b},G:function(a){return a.url||(a.url=E.w(a.u.toUrl(a.id),a.a))},L:function(a){var b,c,d,e,f;b="curl";c="define";d=e=n;if(a&&(f=a.overwriteApi||a.ka,b=a.apiName||a.ea||b,d=a.apiContext||a.da||d,c=a.defineName||a.ga||c,e=a.defineContext||a.fa||e,J&&p(J,"Function")&&(n.curl=J),J=null,M&&p(M,"Function")&&(n.define=M),M=null,!f)){if(d[b]&&d[b]!=C)throw Error(b+" already exists");if(e[c]&&e[c]!=I)throw Error(c+" already exists");}d[b]=
C;e[c]=I},a:function(a){function b(a,b){var d,c,g,s,K;for(K in a){g=a[K];p(g,"String")&&(g={path:a[K]});g.name=g.name||K;s=e;c=u(t(g.name));d=c.l;if(c=c.j)s=f[c],s||(s=f[c]=w(e),s.c=w(e.c),s.d=[]),delete a[K];if(b){c=g;var L=void 0;c.path=t(c.path||c.location||"");L=c.main||"./main";"."==L.charAt(0)||(L="./"+L);c.H=ca(L,c.name+"/");c.a=c.config;c.a&&(c.a=w(e,c.a))}else c={path:t(g.path)};c.M=d.split("/").length;d?(s.c[d]=c,s.d.push(d)):s.n=E.K(g.path,e)}}function c(a){var b=a.c;a.I=RegExp("^("+a.d.sort(function(a,
c){return b[c].M-b[a].M}).join("|").replace(/\/|\./g,"\\$&")+")(?=\\/|$)");delete a.d}var d,e,f,g;"baseUrl"in a&&(a.n=a.baseUrl);"main"in a&&(a.H=a.main);"preloads"in a&&(a.la=a.preloads);"pluginPath"in a&&(a.J=a.pluginPath);if("dontAddFileExt"in a||a.i)a.i=RegExp(a.dontAddFileExt||a.i);d=F;e=w(d,a);e.c=w(d.c);f=a.plugins||{};e.plugins=w(d.plugins);e.s=w(d.s,a.s);e.r=w(d.r,a.r);e.d=[];b(a.packages,h);b(a.paths,m);for(g in f)a=E.m(g+"!","",e),e.plugins[a.substr(0,a.length-1)]=f[g];f=e.plugins;for(g in f)if(f[g]=
w(e,f[g]),a=f[g].d)f[g].d=a.concat(e.d),c(f[g]);for(g in d.c)e.c.hasOwnProperty(g)||e.d.push(g);c(e);return e},O:function(a){var b;(b=a&&a.preloads)&&0<b.length&&A(Q,function(){Q=E.g(E.f(F,z,b,h))})},k:function(a,b){var c,d,e,f;c=b.c;e=ka.test(a)?a:a.replace(b.I,function(a){d=c[a]||{};f=d.a;return d.path||""});return{a:f||F,url:E.K(e,b)}},K:function(a,b){var c=b.n;return c&&!ka.test(a)?t(c)+"/"+a:a},w:function(a,b){return a+((b||F).i.test(a)?"":".js")},$:function(a,b,c){var d=N.createElement("script");
d.onload=d.onreadystatechange=function(c){c=c||n.event;if("load"==c.type||ja[d.readyState])delete P[a.id],d.onload=d.onreadystatechange=d.onerror="",b()};d.onerror=function(){c(Error("Syntax or http error: "+a.url))};d.type=a.ha||"text/javascript";d.charset="utf-8";d.async=!a.ja;d.src=a.url;P[a.id]=d;O.insertBefore(d,ga);return d},S:function(a){var b=[],c;("string"==typeof a?a:a.toSource?a.toSource():a.toString()).replace(la,"").replace(ma,function(a,e,f){f?c=c==f?z:c:c||b.push(e);return""});return b},
V:function(a){var b,c,d,e,f,g;f=a.length;d=a[f-1];e=p(d,"Function")?d.length:-1;2==f?p(a[0],"Array")?c=a[0]:b=a[0]:3==f&&(b=a[0],c=a[1]);!c&&0<e&&(g=h,c=["require","exports","module"].slice(0,e).concat(E.S(d)));return{id:b,p:c||[],v:0<=e?d:function(){return d},o:g}},R:function(a){var b;b=a.v.apply(a.o?a.b:z,a.p);b===z&&a.b&&(b=a.q?a.b=a.q.b:a.b);return b},A:function(a,b){a.v=b.v;a.o=b.o;a.B=b.p;E.g(a)},g:function(a){function b(a,b,c){g[b]=a;c&&q(a,b)}function c(b,c){var d,e,f,g;d=B(1,function(a){e(a);
j(a,c)});e=B(1,function(a){q(a,c)});f=E.T(b,a);(g=f instanceof y&&f.b)&&e(g);A(f,d,a.e,a.b&&function(a){f.b&&(a==ha?e(f.b):a==ia&&d(f.b))})}function d(){a.h(g)}var e,f,g,k,l,q,j;g=[];f=a.B;k=f.length;0==f.length&&d();q=B(k,b,function(){a.D&&a.D(g)});j=B(k,b,d);for(e=0;e<k;e++)l=f[e],l in R?(j(R[l](a),e,h),a.b&&a.t(ha)):l?c(l,e):j(z,e,h);return a},U:function(a){E.G(a);E.$(a,function(){var b=G;G=z;a.ca!==m&&(!b||b.C?a.e(Error(b&&b.C||"define() missing or duplicated: "+a.url)):E.A(a,b))},a.e);return a},
T:function(a,b){var c,d,e,f,g,k,l,q,j,r,s;c=b.m;d=b.Z;e=b.a||F;f=u(c(a));l=f.l;g=f.j||l;q=E.k(g,e);if(f.j)k=g;else if(k=q.a.moduleLoader||q.a.ia)l=g,g=k,q=E.k(k,e);g in H?j=H[g]:(j=E.z(q.a,g,d),j.url=E.w(q.url,q.a),H[g]=j,E.U(j));g==k&&(r=new y,s=e.plugins[k]||e,A(j,function(a){var b,e,f;f=a.dynamic;l="normalize"in a?a.normalize(l,c,j.a)||"":c(l);e=k+"!"+l;b=H[e];if(!(e in H)){b=E.P(s,e,l,d);f||(H[e]=b);var g=function(a){b.h(a);f||(H[e]=a)};g.resolve=g;g.reject=g.error=b.e;a.load(l,b.u,g,s)}r!=b&&
A(b,r.h,r.e,r.t)},r.e));return r||j},Y:function(){var a;if(!p(n.opera,"Opera"))for(var b in P)if("interactive"==P[b].readyState){a=b;break}return a}};R={require:E.X,exports:E.F,module:E.W};C.version="0.7.3";C.config=D;I.amd={plugins:h,jQuery:h,curl:"0.7.3"};F={n:"",J:"curl/plugin",i:/\?|\.js\b/,s:{},r:{},plugins:{},c:{},I:/$^/};J=n.curl;M=n.define;!J||p(J,"Function")?E.L():(n.curl=z,D(J));H.curl=C;H["curl/_privileged"]={core:E,cache:H,config:function(){return F},_define:fa,_curl:C,Promise:y};
var S=this.document;function na(){if(!S.body)return m;T||(T=S.createTextNode(""));try{return S.body.removeChild(S.body.appendChild(T)),T=oa,h}catch(a){return m}}function U(){var a;a=pa[S[qa]]&&na();if(!V&&a){V=h;for(clearTimeout(ra);sa=ta.pop();)sa();ua&&(S[qa]="complete");for(var b;b=va.shift();)b()}return a}function wa(){U();V||(ra=setTimeout(wa,xa))}var qa="readyState",pa={loaded:1,interactive:1,complete:1},va=[],ua=S&&"string"!=typeof S[qa],V=m,xa=10,W,sa,ta=[],ra,oa,T;
W="addEventListener"in this?function(a,b){a.addEventListener(b,U,m);return function(){a.removeEventListener(b,U,m)}}:function(a,b){a.attachEvent("on"+b,U);return function(){a.detachEvent(b,U)}};S&&!U()&&(ta=[W(this,"load"),W(S,"readystatechange"),W(this,"DOMContentLoaded")],ra=setTimeout(wa,xa));define("curl/domReady",function(){function a(a){V?a():va.push(a)}a.then=a;a.amd=h;return a});define("curl/plugin/domReady",["../domReady"],function(a){return{load:function(b,c,d){a(d)}}});
function ya(){var a;a=X[za]("link");a.rel="stylesheet";a.type="text/css";return a}function Aa(a,b,c){Ba.push({url:a,N:b,Q:function(){c(Error(Ca+a))}});b=Da.shift();!b&&Ea.length<Fa&&(b=X.createElement("style"),Ea.push(b),Y.appendChild(b));b&&Ga(b)}function Ga(a){var b,c;b=Ba.shift();c=a.styleSheet;b?(a.onload=function(){b.N(b.aa);Ga(a)},a.onerror=function(){b.Q();Ga(a)},b.aa=c.imports[c.addImport(b.url)]):(a.onload=a.onerror=Z,Da.push(a))}
function Ha(a,b,c){if(!$.load){var d;var e,f;if(!a.href||X.readyState&&"complete"!=X.readyState)d=m;else{d=m;try{if(e=a.sheet)f=e.cssRules,d=null===f,!d&&f&&(e.insertRule("-curl-css-test {}",0),e.deleteRule(0),d=h)}catch(g){d="[object Opera]"!=Object.prototype.toString.call(window.opera)&&/security|denied/i.test(g.message)}}d?c(a.sheet):a.onload==Z||!a.onload||Ia(function(){Ha(a,b,c)},b)}}
function Ja(a,b,c,d){function e(){if(f.onload!=Z&&f.onload){f.onload=f.onerror=Z;var a=function(){!X.readyState||"complete"==X.readyState?b(f.sheet):Ia(a,10)};a()}}var f;f=ya();f.onload=function(){$.load=$.load||h;e()};Ha(f,d,e);f.onerror=function(){$.error=$.error||h;f.onload!=Z&&f.onload&&(f.onload=f.onerror=Z,c(Error(Ca+f.href)))};f.href=a;Y.appendChild(f)}function Z(){}
var za="createElement",Ia=this.setTimeout,X=this.document,Y,Ka=X&&X.createStyleSheet&&!(10<=X.documentMode),Ea=[],Da=[],Ba=[],Fa=12,La,Ca="HTTP or network error: ",$={};X&&(Y=X.head||X.getElementsByTagName("head")[0],La=Ka?Aa:Ja);
define("curl/plugin/css",{normalize:function(a,b){var c,d;if(!a)return a;c=a.split(",");d=[];for(var e=0,f=c.length;e<f;e++)d.push(b(c[e]));return d.join(",")},load:function(a,b,c,d){function e(a){1<k.length&&g.push(a);0==--q&&c(1==k.length?a:g)}function f(a){(c.e||function(a){throw a;})(a)}var g,k,l,q,j;g=[];k=(a||"").split(",");l=d.cssWatchPeriod||50;d=d.cssNoWait;q=k.length;for(j=0;j<k.length;j++){a=k[j];var r;a=b.toUrl(a);a=a.lastIndexOf(".")<=a.lastIndexOf("/")?a+".css":a;d?(r=ya(),r.href=a,
Y.appendChild(r),e(r.sheet||r.styleSheet)):La(a,e,f,l)}},"plugin-builder":"./builder/css",pluginBuilder:"./builder/css"});
}).call(this);
